@@ -1,32 +1,10 @@
 package Devel::hdb::Server;
 
-use strict;
-use warnings;
-
 use HTTP::Server::PSGI;
 our @ISA = qw( HTTP::Server::PSGI );
 
 use Socket qw(IPPROTO_TCP TCP_NODELAY);
 
-our $VERSION = '0.23_15';
-
-sub new {
-    my($class, %args) = @_;
-
-    my %supplied_port_arg;
-    if (exists $args{port}) {
-        $supplied_port_arg{port} = delete $args{port};
-    }
-
-    my $self = $class->SUPER::new(%args);
-    if (%supplied_port_arg) {
-        $self->{port} = $supplied_port_arg{port};
-    }
-
-    $self->{listen_sock} = $args{listen_sock} if exists $args{listen_sock};
-    return $self;
-}
-
 sub accept_loop {
     my($self, $app) = @_;
 
